Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(362)

Unified Diff: ios/chrome/browser/payments/shipping_address_selection_view_controller_unittest.mm

Issue 2710683012: [Payment Request] Payment request summary view pending state (Closed)
Patch Set: rebase Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/payments/shipping_address_selection_view_controller_unittest.mm
diff --git a/ios/chrome/browser/payments/shipping_address_selection_view_controller_unittest.mm b/ios/chrome/browser/payments/shipping_address_selection_view_controller_unittest.mm
index 2d48c61e2f2939b4a465a353c3054bf192ad9f80..d386384d5a1ccfb0e94a869ce5040185099d5c4f 100644
--- a/ios/chrome/browser/payments/shipping_address_selection_view_controller_unittest.mm
+++ b/ios/chrome/browser/payments/shipping_address_selection_view_controller_unittest.mm
@@ -101,8 +101,8 @@ TEST_F(ShippingAddressSelectionViewControllerTest, TestModel) {
// There should stil be 4 items in total.
ASSERT_EQ(4U, static_cast<unsigned int>(NumberOfItemsInSection(0)));
- // Test the loading state.
- [GetShippingAddressSelectionViewController() setIsLoading:YES];
+ // Test the pending state.
+ [GetShippingAddressSelectionViewController() setPending:YES];
[GetShippingAddressSelectionViewController() loadModel];
ASSERT_EQ(1, NumberOfSections());

Powered by Google App Engine
This is Rietveld 408576698